@@ -1,4 +1,4 @@
-from logging import Logger, StreamHandler, Formatter, DEBUG
+from logging import Logger, StreamHandler, Formatter, DEBUG, INFO
 
 
 class ProjectLogger(Logger):
@@ -14,6 +14,7 @@ class ProjectLogger(Logger):
         handler = StreamHandler()
         handler.setFormatter(Formatter('[%(levelname)s] %(message)s'))
         self.addHandler(handler)
+        self.setLevel(DEBUG)
 
     def progress(self, msg):
         """
